==> huaweicloudsdkswr-3.1.133-py2.py3-none-any.whl: huaweicloudsdkswr/v2/model/show_domain_resource_reports_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDomainResourceReportsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_type': 'str',
        'frequency': 'str'
    }

    attribute_map = {
        'resource_type': 'resource_type',
        'frequency': 'frequency'
    }

    def __init__(self, resource_type=None, frequency=None):
        """ShowDomainResourceReportsRequest

        The model defined in huaweicloud sdk

        :param resource_type: 资源类型
        :type resource_type: str
        :param frequency: 频率类型
        :type frequency: str
        """
        
        

        self._resource_type = None
        self._frequency = None
        self.discriminator = None

        self.resource_type = resource_type
        self.frequency = frequency

    @property
    def resource_type(self):
        """Gets the resource_type of this ShowDomainResourceReportsRequest.

        资源类型

        :return: The resource_type of this ShowDomainResourceReportsRequest.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ShowDomainResourceReportsRequest.

        资源类型

        :param resource_type: The resource_type of this ShowDomainResourceReportsRequest.
        :type resource_type: str
        """
        self._resource_type = resource_type

    @property
    def frequency(self):
        """Gets the frequency of this ShowDomainResourceReportsRequest.

        频率类型

        :return: The frequency of this ShowDomainResourceReportsRequest.
        :rtype: str
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this ShowDomainResourceReportsRequest.

        频率类型

        :param frequency: The frequency of this ShowDomainResourceReportsRequest.
        :type frequency: str
        """
        self._frequency = frequency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainResourceReportsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkswr-3.1.145-py2.py3-none-any.whl: huaweicloudsdkswr/v2/model/show_domain_resource_reports_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDomainResourceReportsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resource_type': 'str',
        'frequency': 'str'
    }

    attribute_map = {
        'resource_type': 'resource_type',
        'frequency': 'frequency'
    }

    def __init__(self, resource_type=None, frequency=None):
        r"""ShowDomainResourceReportsRequest

        The model defined in huaweicloud sdk

        :param resource_type: 资源类型
        :type resource_type: str
        :param frequency: 频率类型
        :type frequency: str
        """
        
        

        self._resource_type = None
        self._frequency = None
        self.discriminator = None

        self.resource_type = resource_type
        self.frequency = frequency

    @property
    def resource_type(self):
        r"""Gets the resource_type of this ShowDomainResourceReportsRequest.

        资源类型

        :return: The resource_type of this ShowDomainResourceReportsRequest.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        r"""Sets the resource_type of this ShowDomainResourceReportsRequest.

        资源类型

        :param resource_type: The resource_type of this ShowDomainResourceReportsRequest.
        :type resource_type: str
        """
        self._resource_type = resource_type

    @property
    def frequency(self):
        r"""Gets the frequency of this ShowDomainResourceReportsRequest.

        频率类型

        :return: The frequency of this ShowDomainResourceReportsRequest.
        :rtype: str
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        r"""Sets the frequency of this ShowDomainResourceReportsRequest.

        频率类型

        :param frequency: The frequency of this ShowDomainResourceReportsRequest.
        :type frequency: str
        """
        self._frequency = frequency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainResourceReportsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
